% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{.cbf_split_ints}
\alias{.cbf_split_ints}
\title{Split a whitespace-delimited string into an integer vector.}
\usage{
.cbf_split_ints(x)
}
\description{
Split a whitespace-delimited string into an integer vector.
}
\keyword{internal}
