% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/write.R
\name{.extract_all_cones}
\alias{.extract_all_cones}
\title{Recursively collect all combined cone objects from a constraint object.}
\usage{
.extract_all_cones(cons)
}
\description{
Returns a list of \code{"cone"} objects (one per \code{C_constraint}).
}
\keyword{internal}
