% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{.cbf_svec_idx}
\alias{.cbf_svec_idx}
\title{0-based svec index for lower-triangular (row, col) in an m x m matrix.}
\usage{
.cbf_svec_idx(row, col, m)
}
\arguments{
\item{row}{0-based row index (>= col).}

\item{col}{0-based column index.}

\item{m}{Matrix side-length.}
}
\value{
0-based svec index.
}
\description{
CBF uses column-major lower-triangular ordering:
  column 0: rows 0..(m-1),  column 1: rows 1..(m-1), ...
The cumulative start of column j is  j*m - j*(j-1)/2,
so  k(row, col) = col*m - col*(col-1)/2 + (row - col).
}
\keyword{internal}
