% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{.cbf_build_OP}
\alias{.cbf_build_OP}
\title{Convert parsed CBF sections into an ROI OP object.}
\usage{
.cbf_build_OP(secs)
}
\description{
Convert parsed CBF sections into an ROI OP object.
}
\keyword{internal}
