% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/write.R
\name{.write_bcoord_section}
\alias{.write_bcoord_section}
\title{Write the BCOORD section: constraint constant-term offsets.}
\usage{
.write_bcoord_section(flat, con)
}
\arguments{
\item{flat}{List of chunk records.}

\item{con}{Writable file connection.}
}
\description{
Format (CBF spec Sec.B):
\preformatted{
BCOORD
count
con_idx  value     <- 0-based con_idx; only non-zero values are written
}
}
\section{Sign convention}{

CBF encodes \eqn{Ax + b \in K}.  ROI stores \eqn{Ax - \text{rhs} \in K}.
Therefore \eqn{b_{\text{CBF}} = -\text{rhs}_{\text{ROI}}}.
}

\keyword{internal}
