% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{.cbf_bridge_exp_cone}
\alias{.cbf_bridge_exp_cone}
\title{Reorder a CBF exponential-cone chunk to ROI's coordinate convention.}
\usage{
.cbf_bridge_exp_cone(A_sub, rhs_sub)
}
\description{
Reorder a CBF exponential-cone chunk to ROI's coordinate convention.
}
\keyword{internal}
