% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{.cbf_build_var_constraints}
\alias{.cbf_build_var_constraints}
\title{Build ROI conic constraints induced by nonlinear VAR cone chunks.}
\usage{
.cbf_build_var_constraints(var_chunks, n_total_var, powcones, powstar_cones)
}
\description{
Build ROI conic constraints induced by nonlinear VAR cone chunks.
}
\keyword{internal}
