% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{.cbf_svec_to_n}
\alias{.cbf_svec_to_n}
\title{Recover PSD matrix side-length from svec dimension.}
\usage{
.cbf_svec_to_n(d)
}
\arguments{
\item{d}{Integer. Svec (half-vectorisation) dimension.}
}
\value{
Integer matrix side-length \eqn{n}.
}
\description{
\code{svec(PSD^{nxn})} has dimension \eqn{d = n(n+1)/2}.
Solving for \eqn{n} gives \eqn{n = (-1 + \sqrt{1 + 8d}) / 2}.
}
\keyword{internal}
