% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/write.R
\name{.write_powcones_section}
\alias{.write_powcones_section}
\title{Write a POWCONES or POW*CONES section.}
\usage{
.write_powcones_section(table, keyword, con)
}
\arguments{
\item{table}{List of numeric alpha vectors (one per parametric cone).}

\item{keyword}{Character. Either \code{"POWCONES"} or \code{"POW*CONES"}.}

\item{con}{Writable file connection.}
}
\description{
Format (CBF spec Sec.B):
\preformatted{
POWCONES
N  total_params
k_0           <- chunk header: length of alpha for cone 0
alpha_0[0]
...
alpha_0[k_0-1]
k_1
...
}
}
\keyword{internal}
