% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/write.R
\name{.write_objective_sections}
\alias{.write_objective_sections}
\title{Write OBJACOORD and OBJBCOORD sections for the objective.}
\usage{
.write_objective_sections(obj, con)
}
\arguments{
\item{obj}{ROI objective object (must be an \code{L_objective}).}

\item{con}{Writable file connection.}
}
\description{
\describe{
  \item{OBJACOORD}{Sparse linear-objective coefficients. Format:
    \preformatted{OBJACOORD
count
var_idx  value    <- 0-based var_idx; only non-zero values}}
  \item{OBJBCOORD}{Scalar constant. Format:
    \preformatted{OBJBCOORD
value}}
}
}
\keyword{internal}
