% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{.cbf_bridge_rotated_soc}
\alias{.cbf_bridge_rotated_soc}
\title{Bridge a rotated quadratic cone chunk to a standard SOC chunk.}
\usage{
.cbf_bridge_rotated_soc(A_sub, rhs_sub)
}
\description{
Bridge a rotated quadratic cone chunk to a standard SOC chunk.
}
\keyword{internal}
