% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/write.R
\name{.write_con_section}
\alias{.write_con_section}
\title{Write the CON section: cone chunk declarations for scalar constraints.}
\usage{
.write_con_section(flat, con)
}
\arguments{
\item{flat}{List of chunk records from \code{.flatten_all_constraints}.}

\item{con}{Writable file connection.}
}
\description{
Format (CBF spec Sec.B):
\preformatted{
CON
n_total  n_chunks
CONE_NAME_1  count_1
...
CONE_NAME_k  count_k
}
}
\keyword{internal}
