% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/write.R
\name{.write_cbf_internal}
\alias{.write_cbf_internal}
\title{Internal CBF writer -- writes all sections to an open connection.}
\usage{
.write_cbf_internal(op, con)
}
\description{
Internal CBF writer -- writes all sections to an open connection.
}
\keyword{internal}
