% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read.R
\name{.cbf_parametric_cone}
\alias{.cbf_parametric_cone}
\title{Resolve a parametric power-cone CBF name to an ROI cone object.}
\usage{
.cbf_parametric_cone(cone_nm, count, powcones, powstar_cones)
}
\description{
Resolve a parametric power-cone CBF name to an ROI cone object.
}
\keyword{internal}
