% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/write.R
\name{.roi_cone_dim}
\alias{.roi_cone_dim}
\title{Get the total number of rows for a combined ROI cone object.}
\usage{
.roi_cone_dim(cone)
}
\arguments{
\item{cone}{A \code{"cone"} object returned by \code{K_soc()}, etc.}
}
\value{
Integer total row count.
}
\description{
ROI >= 1.0 uses a unified \code{"cone"} class; the dimension is simply
the length of the \code{$cone} (or \code{$id}) vector.
}
\keyword{internal}
